@@ -56,7 +56,7 @@ class Trainer():
             self.logger = Logger(logger) 
 
         if pretrained:
-            weight_file = download_weights(**config['pretrain'], quiet=config['quiet'])
+            weight_file = download_weights(config['pretrain'], quiet=config['quiet'])
             self.load_weights(weight_file)
 
         self.iter = 0
