@@ -18,8 +18,8 @@ class Cfg(dict):
 
     @staticmethod
     def load_config_from_file(fname):
-        base_config = download_config(url_config['base'])
-
+        #base_config = download_config(url_config['base'])
+        base_config = {}
         with open(fname, encoding='utf-8') as f:
             config = yaml.safe_load(f)
         base_config.update(config)
